@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::EOL; # git description: 0.17-10-gd9ed619
+package Dist::Zilla::Plugin::Test::EOL; # git description: 0.18-26-gf608025
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Author tests making sure correct line endings are used
 # KEYWORDS: plugin test testing author development whitespace newline linefeed formatting
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Moose;
 use Path::Tiny;
@@ -59,7 +60,10 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-         map { $_ => $self->$_ } qw(filename trailing_whitespace finder),
+        trailing_whitespace => $self->trailing_whitespace ? 1 : 0,
+        filename => $self->filename,
+        finder => [ sort @{ $self->finder } ],
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
     return $config;
 };
@@ -114,8 +118,8 @@ sub register_prereqs
     my $self = shift;
     $self->zilla->register_prereqs(
         {
-            type  => 'requires',
             phase => 'develop',
+            type  => 'requires',
         },
         'Test::More' => '0.88',
         'Test::EOL' => '0',
@@ -196,7 +200,7 @@ Dist::Zilla::Plugin::Test::EOL - Author tests making sure correct line endings a
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
@@ -260,6 +264,17 @@ Test::EOL
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-EOL>
+(or L<bug-Dist-Zilla-Plugin-Test-EOL@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-EOL@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHORS
 
 =over 4
@@ -278,13 +293,6 @@ Karen Etheridge <ether@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Florian Ragwitz <rafl@debian.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Olivier Mengué Shlomi Fish
@@ -301,6 +309,13 @@ Shlomi Fish <shlomif@shlomifish.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2010 by Florian Ragwitz <rafl@debian.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __DATA__
@@ -308,7 +323,7 @@ ___[ __TEST__ ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
+# this test was generated with {{ ref $plugin }} {{ $plugin->VERSION }}
 
 use Test::More 0.88;
 use Test::EOL;
